# KymoTools
A collection of tools to process kymographs.  Functions include peak detection and tracking, MSD calculation and plotting.

## Installation
This package can be installed using either pip or conda.  Depending on your package manager, please use one of the following to install KymoTools and its dependencies.

### Conda
```
conda install sjcross::kymotools
```

### Pip
```
pip install kymotools
```

## Example notebooks
Example notebooks using these tools can be found in the [kymotools-notebooks](https://github.com/sjcross/kymotools-notebooks) repository.
